.. _straylight_step:

======================
Stray Light Correction
======================

.. toctree::
   :maxdepth: 2

   main.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.straylight
